==> percona-xtrabackup-80_8.0.35-31.orig.tar.gz: percona-xtrabackup-8.0.35-31/storage/ndb/src/kernel/blocks/dbacc/Dbqacc.hpp <==
/*
   Copyright (c) 2019, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef DBQACC_H
#define DBQACC_H

#ifndef DBQACC_STATE_EXTRACT
#include "Dbacc.hpp"
#endif

#define JAM_FILE_ID 521

class Dbqacc : public Dbacc
{
  friend class DbqaccProxy;

public:
  Dbqacc(Block_context& ctx,
         Uint32 instanceNumber = 0);
  virtual ~Dbqacc();

  static Uint64 getTransactionMemoryNeed();
private:
  BLOCK_DEFINES(Dbqacc);
};

#undef JAM_FILE_ID
#endif

==> percona-xtrabackup-84_8.4.0-2.orig.tar.gz: percona-xtrabackup-8.4.0-2/storage/ndb/src/kernel/blocks/dbacc/Dbqacc.hpp <==
/*
   Copyright (c) 2019, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef DBQACC_H
#define DBQACC_H

#ifndef DBQACC_STATE_EXTRACT
#include "Dbacc.hpp"
#endif

#define JAM_FILE_ID 521

class Dbqacc : public Dbacc {
  friend class DbqaccProxy;

 public:
  Dbqacc(Block_context &ctx, Uint32 instanceNumber = 0);
  virtual ~Dbqacc();

  static Uint64 getTransactionMemoryNeed();

 private:
  BLOCK_DEFINES(Dbqacc);
};

#undef JAM_FILE_ID
#endif
